#' @title Similiarity of Matrices Coefficients
#' @description Computation and visualization of matrix correlation coefficients.
#'   The main method is the Similarity of Matrices Index, while various related
#'   measures like r1, r2, r3, r4, Yanai's GCD, RV, RV2 and adjusted RV are included
#'   for comparison.
#' @seealso \code{\link{SMI}}, \code{\link{plot.SMI}} (print.SMI/summary.SMI), \code{\link{RV}} (RV2/RVadj), \code{\link{r1}} (r2/r3/r4/GCD), \code{\link{allCorrelations}} (matrix correlation comparison).
#' @name MatrixCorrelation
"_PACKAGE"
